import { LogLevel } from './log_level';
import { MetricMeasurementPoint } from './metric_measurement_point';
/**
 * Describes a single log entry.
 * Contains information about the Correlation, ProcessModel and
 * FlowNodeInstance to which the entry belongs,
 * aswell as a timestamp, LogLevel and the concrete message that was logged.
 *
 * When logging a metric, the message will be something like "onEnter", "onExit", etc.
 *
 * The properties here are ordered in the same manner as they are in the
 * actual log file.
 */
export declare class LogEntry {
    timeStamp: Date;
    correlationId: string;
    processModelId: string;
    processInstanceId: string;
    flowNodeInstanceId?: string;
    flowNodeId?: string;
    logLevel: LogLevel;
    message: string;
    measuredAt: MetricMeasurementPoint;
    tokenPayload: any;
    error?: Error;
}
